package org.springblade.ftpdemo.task;

import lombok.AllArgsConstructor;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.ftpdemo.service.Method;
import org.springblade.ftpdemo.service.NbmsEntApplyServcie;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.Date;

/**
 * 三、	标识解析企业主体信息上报
 *
 * @author laifeng
 * @since 2022/11/29
 */
@Component
@EnableScheduling
@AllArgsConstructor
public class IdentificationUpTask {
    private final NbmsEntApplyServcie nbmsEntApplyServcie;
    private final Method method;

//    @Scheduled(cron = "0/20 * * * * ? ")
    public void refreshAliDeviceStatus() {
        // 标识解析企业主体信息上报检测新增并上传
        threePackMethod(0);
        // 标识解析企业主体信息上报检测更新并上传
        threePackMethod(1);

        fourPackMethod(0);
        fourPackMethod(1);

        fivePackMethod(0);
        fivePackMethod(1);


    }

    /**
     * 三、	标识解析企业主体信息上报
      * @param type 0 新增 1 更新
     */
    private void threePackMethod(Integer type) {
        // 时间格式化
        Date now = DateUtil.now();
        Date date = DateUtil.minusDays(now, 1);
        String yyyyMMdd = DateUtil.format(date, "yyyyMMdd");
        String yyyyMMddToday = DateUtil.format(now, "yyyyMMdd");
        Boolean temp = false;

        try {
            temp = method.creatIdentificationUpFile(type, yyyyMMdd, yyyyMMddToday);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        // 如果没有生成文件，可直接结束
        if (!temp) {
            return;
        }


        String fileName = "d://aaa//test.txt";
        // 要上传的目录
        String upSrc = "/001/" + yyyyMMdd;
        // 表名（文件名的一部分）
        String tableName = "SDQN-basic_identification-";
        String operationName = "";
        if (type == 0) {
            // 操作类型为新增
            operationName = "-add.bin";
        }
        if (type == 1) {
            // 操作类型为更新
            operationName = "-update.bin";
        }
        try {
            method.upMethod(fileName, upSrc, tableName, operationName);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }

    }

    /**
     * 四、	标识解析企业主体信息上报
     * @param type 0 新增 1 更新
     */
    private void fourPackMethod(Integer type){
        // 时间格式化
        Date now = DateUtil.now();
        Date date = DateUtil.minusDays(now, 1);
        String yyyyMMdd = DateUtil.format(date, "yyyyMMdd");
        String yyyyMMddToday = DateUtil.format(now, "yyyyMMdd");
        Boolean temp = false;

        try {
            temp = method.creatForUpFile(type, yyyyMMdd, yyyyMMddToday);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        // 如果没有生成文件，可直接结束
        if (!temp) {
            return;
        }

        String fileName = "d://aaa//test.txt";
        // 要上传的目录
        String upSrc = "/002/" + yyyyMMdd;
        // 表名（文件名的一部分）
        String tableName = "SDQN-basic_identification_ip-";
        String operationName = "";
        if (type == 0) {
            // 操作类型为新增
            operationName = "-add.bin";
        }
        if (type == 1) {
            // 操作类型为更新
            operationName = "-update.bin";
        }
        try {
            method.upMethod(fileName, upSrc, tableName, operationName);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 五、	标识注册企业主体信息上报
     * @param type
     */
    private void fivePackMethod(Integer type){
        // 时间格式化
        Date now = DateUtil.now();
        Date date = DateUtil.minusDays(now, 1);
        String yyyyMMdd = DateUtil.format(date, "yyyyMMdd");
        String yyyyMMddToday = DateUtil.format(now, "yyyyMMdd");
        Boolean temp = false;

        try {
            temp = method.creatFiveUpFile(type, yyyyMMdd, yyyyMMddToday);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        // 如果没有生成文件，可直接结束
        if (!temp) {
            return;
        }


        String fileName = "d://aaa//test.txt";
        // 要上传的目录
        String upSrc = "/003/" + yyyyMMdd;
        // 表名（文件名的一部分）
        String tableName = "SDQN-basic_registered-";
        String operationName = "";
        if (type == 0) {
            // 操作类型为新增
            operationName = "-add.bin";
        }
        if (type == 1) {
            // 操作类型为更新
            operationName = "-update.bin";
        }
        try {
            method.upMethod(fileName, upSrc, tableName, operationName);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
